__author__ = 'jaddison'

import posixpath
import datetime
import urllib
import os

from django import template
from django.conf import settings

try:
    # finders won't exist if we're not using Django 1.3+
    from django.contrib.staticfiles import finders
except ImportError:
    finders = None


register = template.Library()


@register.tag(name="media")
def do_media(parser, token):
    return CacheBusterTag(token, True)


@register.tag(name="static")
def do_static(parser, token):
    return CacheBusterTag(token, False)


class CacheBusterTag(template.Node):
    def __init__(self, token, is_media):
        self.is_media = is_media

        try:
            tokens = token.split_contents()
        except ValueError:
            raise template.TemplateSyntaxError, "'%r' tag must have one or two arguments" % token.contents.split()[0]

        self.path = tokens[1]
        self.force_timestamp = len(tokens) == 3 and tokens[2] or False

    def render(self, context):
        # self.path may be a template variable rather than a simple static file string
        try:
            path = template.Variable(self.path).resolve(context)
        except template.VariableDoesNotExist:
            path = self.path

        self.path = posixpath.normpath(urllib.unquote(self.path)).lstrip('/')

        if self.is_media:
            url_prepend = settings.MEDIA_URL
            unique_string = self.get_file_modified(os.path.join(settings.MEDIA_ROOT, self.path))
        else:
            # django versions < 1.3 don't have a STATIC_URL, so fall back to MEDIA_URL
            url_prepend = getattr(settings, "STATIC_URL", settings.MEDIA_URL)
            if settings.DEBUG and finders:
                absolute_path = finders.find(self.path)
            else:
                # django versions < 1.3 don't have a STATIC_ROOT, so fall back to MEDIA_ROOT
                absolute_path = os.path.join(getattr(settings, 'STATIC_ROOT', settings.MEDIA_ROOT), self.path)

            if self.force_timestamp:
                unique_string = self.get_file_modified(absolute_path)
            else:
                unique_string = getattr(settings, 'CACHEBUSTER_UNIQUE_STRING', self.get_file_modified(absolute_path))

        return url_prepend + path + '?' + unique_string

    def get_file_modified(self, path):
        return datetime.datetime.fromtimestamp(os.path.getmtime(os.path.abspath(path))).strftime('%S%M%H%d%m%y')




__author__ = 'jaddison'

import os

def unique_string():
    base_dir = os.path.dirname(os.path.abspath(__file__))
    while True:
        git_dir = os.path.normpath(os.path.join(base_dir, '.git'))
        if os.path.isdir(git_dir):
            break

        new_base_dir = os.path.dirname(base_dir)

        # if they are the same, then we've reached the root directory and
        # can't move up anymore - there is no .git directory.
        if new_base_dir == base_dir:
            return None

        base_dir = new_base_dir

    # Read the HEAD ref
    fhead = open(os.path.join(git_dir, 'HEAD'), 'r')
    ref_name = fhead.readline().split(" ")[1].strip()
    fhead.close()

    # Read the commit id
    fref = open(os.path.join(git_dir, ref_name), 'r')
    ref = fref.readline().strip()
    fref.close()

    return unicode(ref)



import os
from distutils.core import setup

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name = 'django-cachebuster',
    description = 'Django 1.3 ready cache busting app',
    long_description=read('README.rst'),
    author='James Addison',
    author_email='code@scottisheyes.com',
    packages = ['cachebuster','cachebuster.templatetags','cachebuster.detectors'],
    version = '0.1.1',
    url='http://github.com/jaddison/django-cachebuster',
    keywords=[],
    license='BSD',
    classifiers=[
      'Development Status :: 3 - Alpha',
      'Intended Audience :: Developers',
      'License :: OSI Approved :: BSD License',
      'Topic :: Internet :: WWW/HTTP :: WSGI',
      'Framework :: Django',
    ],
)